@@ -1,7 +1,7 @@
 """Library to initiate backend RIME service requests."""
 import json
 import logging
-from datetime import date, datetime, timedelta
+from datetime import date, datetime
 from enum import Enum
 from http import HTTPStatus
 from pathlib import Path
@@ -12,7 +12,7 @@ import importlib_metadata
 from deprecated import deprecated
 from urllib3.util import Retry
 
-from rime_sdk.firewall import Firewall, get_reference_set_source
+from rime_sdk.firewall import Firewall
 from rime_sdk.image_builder import RIMEImageBuilder
 from rime_sdk.internal.config_parser import convert_config_to_swagger
 from rime_sdk.internal.file_upload import FileUploadModule
@@ -21,29 +21,21 @@ from rime_sdk.internal.security_config_parser import (
     convert_model_info_to_dict,
     model_info_from_dict,
 )
-from rime_sdk.internal.swagger_utils import (
-    get_bin_size_swagger,
-    get_data_params_swagger,
-    get_model_task_enum_swagger,
-    location_args_to_data_location_swagger,
-    valid_model_task_for_data_type,
-)
+from rime_sdk.internal.swagger_utils import get_swagger_data_type_enum
 from rime_sdk.internal.throttle_queue import ThrottleQueue
 from rime_sdk.job import BaseJob, ContinuousTestJob, FileScanJob, ImageBuilderJob, Job
 from rime_sdk.project import Project
 from rime_sdk.swagger import swagger_client
-from rime_sdk.swagger.swagger_client import ApiClient, RimeDataLocation
+from rime_sdk.swagger.swagger_client import ApiClient
 from rime_sdk.swagger.swagger_client.models import (
     ListImagesRequestPipLibraryFilter,
     ManagedImagePackageRequirement,
     ManagedImagePackageType,
     ManagedImagePipRequirement,
     RimeBaseImageType,
-    RimeCreateFirewallFromDataRequest,
     RimeCreateImageRequest,
     RimeCustomImage,
     RimeCustomImageType,
-    RimeDataType,
     RimeJobMetadata,
     RimeJobStatus,
     RimeJobType,
@@ -92,21 +84,6 @@ def get_job_status_enum(job_status: str) -> str:
         )
 
 
-def get_swagger_data_type_enum(data_type: str) -> str:
-    """Get RimeDataType enum value from string."""
-    if data_type == "tabular":
-        return RimeDataType.TABULAR
-    elif data_type == "nlp":
-        return RimeDataType.NLP
-    elif data_type == "images":
-        return RimeDataType.IMAGES
-    else:
-        raise ValueError(
-            f"Got unknown data type ({data_type}), "
-            f"should be one of: `tabular`, `nlp`, `images`"
-        )
-
-
 class Client:
     """The `Client` provides an interface to RIME's backend\
         services for creating projects, starting stress test jobs,\
@@ -1191,108 +1168,6 @@ class Client:
         project = self.get_project(project_id)
         return project.get_firewall()
 
-    def create_firewall_from_data(
-        self,
-        name: str,
-        project_id: str,
-        data_type: str,
-        model_task: str,
-        bin_size: str,
-        data_params: Dict,
-        rolling_window_duration: Optional[timedelta] = None,
-        reference_set_time_bin: Optional[Tuple[datetime, datetime]] = None,
-        reference_set_file_path: Optional[str] = None,
-        run_ct_schedule: bool = False,
-        location_type: Optional[str] = None,
-        location_info: Optional[dict] = None,
-    ) -> Tuple[BaseJob, str]:
-        """Create a firewall directly from data without a stress test.
-
-        Arguments:
-            name: str
-                FW name.
-            project_id: str
-                Identifier for the project where the resulting test run will be stored.
-            data_type: str
-                Data type. Can be `tabular` or `nlp`.
-            model_task: str
-                Model task. Can be `Binary Classification`, `Multi-class
-                Classification`, `Regression`, `Ranking`, `Named Entity Recognition`,
-                `Natural Language Inference`, or `Text Classification`.
-            bin_size: str
-                Bin size. Can be `year`, `month`, `week`, `day`, `hour`.
-            data_params: Dict
-                Information needed to process data from the data location provided.
-                By default, these are obtained from your reference information.
-                Eg. `pred_col`, `timestamp_col`, `label_col`, etc...
-            rolling_window_duration: Optional[timedelta]
-                Fixed Time duration of rolling window.
-                Only one of rolling_window_seconds, reference_set_time_bin, or
-                reference_set_file_path may be set. If this is specified, then data
-                location and its related parameters must be set.
-            reference_set_time_bin: Optional[Tuple[datetime, datetime]]
-                Time bin of reference set can be set for firewall running scheduled ct.
-                Only one of rolling_window_seconds, reference_set_time_bin, or
-                reference_set_file_path may be set. If this is specified, then data
-                location and its related parameters must be set.
-            reference_set_file_path: str
-                File path for reference set in S3 bucket.
-                Only one of rolling_window_seconds, reference_set_time_bin, or
-                reference_set_file_path may be set.
-            run_ct_schedule: bool
-                Flag for ct scheduler.
-            location_type: Optional[str]
-                Type of the data location that ScheduledCT will pull data from.
-            location_info: Optional[Dict]
-                Information needed to access the data location provided.
-
-        Returns:
-            A tuple containing the job for profiling the reference set and the
-            firewall ID.
-
-        Raises:
-            ValueError
-                If the provided values are invalid.
-        """
-        data_type_sw = get_swagger_data_type_enum(data_type)
-        model_task_sw = get_model_task_enum_swagger(model_task)
-        if not valid_model_task_for_data_type(model_task_sw, data_type_sw):
-            raise ValueError(f"Model task {model_task} not valid for {data_type} data.")
-        if reference_set_file_path is None and location_type is None:
-            raise ValueError("Data location required if no file path specified.")
-
-        data_location_sw: Optional[RimeDataLocation] = None
-        if location_type is not None:
-            data_location_sw = location_args_to_data_location_swagger(
-                location_type=location_type,
-                location_info=location_info,
-                data_params=data_params,
-                data_type=data_type_sw,
-            )
-
-        data_params_sw = get_data_params_swagger(data_params, data_type_sw)
-        req = RimeCreateFirewallFromDataRequest(
-            name=name,
-            project_id=project_id,
-            data_type=data_type_sw,
-            model_task=model_task_sw,
-            run_ct_schedule=run_ct_schedule,
-            bin_size=get_bin_size_swagger(bin_size),
-            reference_set_source=get_reference_set_source(
-                reference_set_time_bin=reference_set_time_bin,
-                rolling_window_duration=rolling_window_duration,
-                file_path=reference_set_file_path,
-            ),
-            data_location_info=data_location_sw,
-            data_params=data_params_sw,
-        )
-        with RESTErrorHandler():
-            api = swagger_client.ModelTestingApi(self._api_client)
-            response = api.model_testing_create_firewall_from_data(body=req)
-            job = self.get_job(response.stress_test_job.job_id)
-            firewall_id = response.firewall.id
-        return job, firewall_id
-
     @deprecated("This method is deprecated, please use upload_file.")
     def upload_dataset_file(
         self, file_path: Union[Path, str], upload_path: Optional[str] = None
